@@ -1,13 +1,13 @@
 /*
- *   Copyright (c) 1996-2000 Lucent Technologies.
+ *   Copyright (c) 1996-2001 Lucent Technologies.
  *   See README file for details.
+ *
+ *
+ *
+ *  Functions for determining bandwidth; smoothing neighborhood
+ *  and smoothing weights.
  */
 
-/*
-  Functions for determining bandwidth; smoothing neighborhood
-  and smoothing weights.
-*/
-
 #include "local.h"
 
 extern vari *vb;
@@ -44,7 +44,7 @@ INT d, kt, *sty;
     return(sqrt(s));
   }
 
-  ERROR(("rho: invalid kt"));
+  lfERROR(("rho: invalid kt"));
   return(0.0);
 }
 
